SecuritySettings class

Constructors

SecuritySettings({bool? enableGoogleServices, bool? useRoot, bool? useEmulator, bool? useDeveloperMode, bool? useAdb, bool? useDebug})

Properties

enableGoogleServices ↔ bool?
Allows you to enable or disable SDK features that utilize Google Services.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useAdb ↔ bool?
Allows you to enable or disable SDK to run in Android Debug Bridge (ADB) debugging mode.
getter/setter pair
useDebug ↔ bool?
Allows you to enable or disable SDK to run in a debug mode application.
getter/setter pair
useDeveloperMode ↔ bool?
Allows you to enable or disable SDK to run in devices with developer mode activated.
getter/setter pair
useEmulator ↔ bool?
Allows you to enable or disable SDK to run in emulated devices.
getter/setter pair
useRoot ↔ bool?
Allows you to enable or disable SDK to run in rooted devices.
getter/setter pair

Methods

asMap() → Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited