SensorSettingsAndroid class

Constructors

SensorSettingsAndroid({int? luminositySensorSettings, double? orientationSensorSettings, StabilitySensorSettings? stabilitySensorSettings, bool? disableLuminositySensor, bool? disableOrientationSensor, bool? disableStabilitySensor})

Properties

disableLuminositySensor ↔ bool?
Disable luminosity sensor
getter/setter pair
disableOrientationSensor ↔ bool?
Disable orientation sensor
getter/setter pair
disableStabilitySensor ↔ bool?
Disable stability sensor
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
luminositySensorSettings ↔ int?
Defines threshold between acceptable/unacceptable ambient brightness. The lower the value set, the less sensitive the orientation sensor will be.
getter/setter pair
orientationSensorSettings ↔ double?
Defines threshold between correct/incorrect device orientation. The higher the value set, the less sensitive the orientation sensor will be.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stabilitySensorSettings ↔ StabilitySensorSettings?
Defines stability sensor settings.
getter/setter pair

Methods

asMap() → Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited