DocumentCaptureFlow class

Constructors

DocumentCaptureFlow({required DocumentType documentType, InstructionalPopupSettingsAndroid? androidCustomization, InstructionalPopupSettingsIOS? iOSCustomization})

Properties

androidCustomization ↔ InstructionalPopupSettingsAndroid?
Customize the instructional popup document illustration and label.
getter/setter pair
documentType ↔ DocumentType
Identifies which document will be requested for capture in the respective step.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iOSCustomization ↔ InstructionalPopupSettingsIOS?
Customize the instructional popup document illustration and label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMap() → Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited