Capture class

Constructors

Capture(String? imagePath, String? imageUrl, String? label, double? quality)
Capture.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imagePath ↔ String?
Full path of the image file on the user's device.
getter/setter pair
imageUrl ↔ String?
URL of the document file on the Caf's server. This URL has an expiry time, which can be set with the setUrlExpirationTime method.
getter/setter pair
label ↔ String?
Label of the captured document, for example: cnh_front, rg_back, passport...
getter/setter pair
quality ↔ double?
Quality inferred by the document quality algorithm, varying between 0 and 5.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited