DocumentDetectorEventSuccess class

This class represents a successful document capture event. The user document has been successfully captured, and the URLs for download the captures have been returned.

Implemented types

Constructors

DocumentDetectorEventSuccess({List<Capture>? captures, String? documentType, String? trackingId})
const

Properties

captures → List<Capture>?
The captures of the document
final
documentType → String?
The type of the document
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingId → String?
The tracking id of the execution
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited