IOSSettings class

Constructors

IOSSettings({SensorSettingsIOS? sensorSettings, double? captureCompressionQuality, bool? enableManualCapture, int? manualCaptureActivationDelay, bool? enableMultiLanguage, IOSCameraResolution? cameraResolution, CustomLayoutIOS? customLayout})

Properties

cameraResolution ↔ IOSCameraResolution?
Set document capture resolution. The options are fullHd and ultraHd. By default resolution is fullHd.
getter/setter pair
captureCompressionQuality ↔ double?
Set the quality in the compression process. By default, all captures go through compression. The method expects values between 0.8 and 1.0 as a parameter, where 1.0 is the best compression quality.
getter/setter pair
customLayout ↔ CustomLayoutIOS?
Customize you iOS app layout settings.
getter/setter pair
enableManualCapture ↔ bool?
Enable the manual capture option. With this configuration enabled, you can specify the time - in seconds - until manual capture is activated using the manualCaptureActivationDelay parameter. By default, this time is set to 45 seconds.
getter/setter pair
enableMultiLanguage ↔ bool?
This configuration enables or disables multi-language support (English, Spanish, Brazilian Portuguese). If disabled, the language will default to Brazilian Portuguese.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualCaptureActivationDelay ↔ int?
Set the time delay to enable manual capture option for the user. By default, this time is set to 45 seconds. To enable the manual capture feature, use enableManualCapture: true parameter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensorSettings ↔ SensorSettingsIOS?
Configure the ambient luminosity, device orientation, and stability sensor threshold parameters to ensure the document is captured in optimal conditions.
getter/setter pair

Methods

asMap() → Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited