CustomLayoutIOS class

Constructors

CustomLayoutIOS({String? primaryColor, FeedbackColorsIOS? feedbackColors, String? fontStyle})

Properties

feedbackColors ↔ FeedbackColorsIOS?
Customize the UI feedback colors to be displayed.
getter/setter pair
fontStyle ↔ String?
Change the font applyed to the SDK.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
primaryColor ↔ String?
Change the button components primary color.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMap() → Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited