SensorSettingsIOS class

Constructors

SensorSettingsIOS({double? luminositySensorSettings, double? orientationSensorSettings, double? stabilitySensorSettings})

Properties

hashCode → int
The hash code for this object.
no setterinherited
luminositySensorSettings ↔ double?
Defines threshold between acceptable/unacceptable ambient brightness.
getter/setter pair
orientationSensorSettings ↔ double?
Defines the threshold between correct/incorrect device orientation based on the variation of the last two accelerometer sensor readings collected from the device.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stabilitySensorSettings ↔ double?
Defines the threshold between stable/unstable device based on the variation of the last two gyro sensor readings collected from the device.
getter/setter pair

Methods

asMap() → Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited